@@ -1,5 +1,14 @@
 #![doc(html_logo_url = "https://avatars.githubusercontent.com/u/54848194?v=4")]
 
+//! # BTW I USE ARCH
+//!
+//! Hello world!
+
+pub enum Devices {
+    Pixelbook,
+    Pixel5,
+}
+
 pub trait Empty {}
 
 pub trait Any {}
